package cz.moneta.test.regression.backoffice.callcenter.jenkinstests;

import cz.moneta.test.dsl.Harness;
import cz.moneta.test.dsl.util.credentials.Keys;
import cz.moneta.test.dsl.util.task.ufo.operations.OperationsTasks;
import cz.moneta.test.harness.annotations.JiraTestCase;
import cz.moneta.test.harness.annotations.TestCase;
import cz.moneta.test.harness.annotations.TestScenario;
import cz.moneta.test.harness.support.auth.Credentials;
import cz.moneta.test.harness.support.auth.Key;
import org.junit.jupiter.api.BeforeAll;

import static cz.moneta.test.harness.annotations.Environment.PPE;
import static cz.moneta.test.harness.annotations.Environment.TST1;

@TestScenario(name = "Cards lookup view applications")
public class CardsLookupViewApplications {
    private String rcOfExistingClient;
    private OperationsTasks operationsTasks;

    @BeforeAll
    public void getInfo(Harness harness) {
        operationsTasks = harness.tasks().ufo().operations();
        rcOfExistingClient = harness.getSystemOrConfigValue("cc.creditCardClient.rc");
    }

    @TestCase(name = "Cards lookup view applications", environments = {PPE, TST1})
    @JiraTestCase(id = "CC-T2163")
    public void cardsLookupViewApplications(Harness harness, @Key(Keys.ufo.banka.banker) Credentials credentials) {

        harness.withUfo()
                .openLoginPage()
                .then(operationsTasks.login().withCredentials(credentials))
                .clickCardsRadio()
                .clickRcRadio()
                .fillSearchInput(rcOfExistingClient)
                .clickSearch()
                .onClientDetailsPage()
                .assertCreditCardsTab()
                .assertCreditCardContractState()
                .openApplicationList()
                .assertApplicationDetailButton()
                .assertApplicationLoadButton()
                .assertApplicationLoadAllButton()
                .assertApplicationCopyButton()
                .assertApplicationStornoButton()
                .assertApplicationFinishButton()
                .assertApplicationDecisionButton()
                .clickClientDetail()
                .checkClientRc(rcOfExistingClient);

    }
}
